<?php

namespace App\Controller;

use App\Entity\GlobalParameter;
use App\Entity\SolidoumeItem;
use App\Entity\SolidoumeParameter;
use App\Form\Type\SolidoumeFormType;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Security;
use Twig\Environment;

class SolidoumeController extends AbstractController
{
    private $em;
    private $security;
    private $mailer;
    private $templating;

    public function __construct(EntityManagerInterface $em, Security $security, \Swift_Mailer $mailer, Environment $templating)
    {
        $this->em = $em;
        $this->security = $security;
        $this->mailer = $mailer;
        $this->templating = $templating;
    }

    /**
     * @Route("/ssa/desinscription", name="solidoume_unsubscribe")
     */
    public function unsubscribeAction(Request $request)
    {
        if (!(null != $this->security->getUser()->getAdherent() && $this->security->getUser()->isGranted('ROLE_ADHERENT'))) {
            $this->addFlash(
                'error',
                'Page inaccessible, vous devez être connecté en adhérent !'
            );

            return $this->redirectToRoute('index');
        }
        $solidoumeItem = $this->em->getRepository(SolidoumeItem::class)->findOneBy(['adherent' => $this->security->getUser()->getAdherent(), 'enabled' => true]);
        $solidoumeItem->setEnabled(false);
        $this->em->persist($solidoumeItem);
        $this->em->flush();

        $solidoumeParam = $this->em->getRepository(SolidoumeParameter::class)->findTheOne();
        $name = 'la sécurite sociale alimentaire';
        if (null != $solidoumeParam) {
            $name = $solidoumeParam->getName();
        }
        $this->addFlash(
            'success',
            'Désinscription à ' . $name . ' bien prise en compte !'
        );

        return $this->redirectToRoute('index');
    }

    /**
     * @Route("/ssa/adherer", name="solidoume_adherer")
     */
    public function adhererAction(Request $request)
    {
        if (!(null != $this->security->getUser()->getAdherent() && $this->security->getUser()->isGranted('ROLE_ADHERENT'))) {
            $this->addFlash(
                'error',
                'Page inaccessible, vous devez être connecté en adhérent !'
            );

            return $this->redirectToRoute('index');
        }

        $solidoumeParam = $this->em->getRepository(SolidoumeParameter::class)->findTheOne();
        if (empty($solidoumeParam)) {
            $this->addFlash(
                'error',
                'Programme non configuré !'
            );

            return $this->redirectToRoute('index');
        }

        $data = $this->em->getRepository(SolidoumeItem::class)->findOneBy(['adherent' => $this->security->getUser()->getAdherent(), 'enabled' => true]);
        $alreadyExist = false;
        if (!empty($data)) {
            $alreadyExist = true;
        }
        $form = $this->createForm(SolidoumeFormType::class, $data);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $solidoumeItem = $form->getData();
            $this->em->persist($solidoumeItem);
            $this->em->flush();
            // if (!$alreadyExist) {
            $this->sendMail($solidoumeItem);
            // }

            $this->addFlash(
                'success',
                $solidoumeParam->getName() . ' : Merci de votre participation !'
            );
            $referer = $request->request->get('referer');
            if ($referer && !$request->isXmlHttpRequest()) {
                return $this->redirect($referer);
            } elseif (!$request->isXmlHttpRequest()) {
                return new Response('', Response::HTTP_BAD_REQUEST);
            }
        }

        return $this->render('@kohinos/solidoume/index.html.twig', [
            'form' => $form->createView(),
            'param' => $solidoumeParam,
        ]);
    }

    private function sendMail(SolidoumeItem $solidoumeItem)
    {
        $subject = $this->em->getRepository(SolidoumeParameter::class)->getValueOf('name');
        $from = $this->em->getRepository(GlobalParameter::class)->val(GlobalParameter::MLC_NOTIF_EMAIL);
        $mail = (new \Swift_Message($subject))
            ->setFrom($from)
            ->setTo($solidoumeItem->getUser()->getEmail())
            ->setBody(
                $this->templating->render(
                    '@kohinos/email/solidoume/confirm.html.twig',
                    [
                        'subject' => $subject,
                        'item' => $solidoumeItem,
                    ]
                ),
                'text/html'
            );
        $this->mailer->send($mail);
    }
}
